@@ -36,6 +36,7 @@
 #include <QString>
 #include <QStringList>
 #include <QTextCodec>
+#include <QDir>
 
 K_PLUGIN_FACTORY(FileViewGitPluginFactory, registerPlugin<FileViewGitPlugin>();)
 
@@ -149,7 +150,7 @@ bool FileViewGitPlugin::beginRetrieval(const QString& directory)
     m_versionInfoHash.clear();
 
     // ----- find files with special status -----
-    process.start(QLatin1String("git status --porcelain -z --ignored"));
+    process.start(QLatin1String("git status --porcelain -z -u --ignored"));
     while (process.waitForReadyRead()) {
         char buffer[1024];
         while (readUntilZeroChar(&process, buffer, sizeof(buffer)) > 0 ) {
@@ -271,7 +272,7 @@ QList<QAction*> FileViewGitPlugin::contextMenuFilesActions(const KFileItemList&
     Q_ASSERT(!items.isEmpty());
 
     if (!m_pendingOperation){
-        m_contextDir.clear();
+        m_contextDir = QFileInfo(items.first().localPath()).canonicalPath();
         m_contextItems.clear();
         foreach(const KFileItem& item, items){
             m_contextItems.append(item);
@@ -623,7 +624,7 @@ void FileViewGitPlugin::startGitCommandProcess()
     if (m_command == "add" && !item.isDir()){
         arguments<< QLatin1String("-f");
     }
-    arguments << item.localPath();
+    arguments << item.url().fileName();
     m_process.start(QLatin1String("git"), arguments);
     // the remaining items of m_contextItems will be executed
     // after the process has finished (see slotOperationFinished())
